<?php
  require ("strona.php");

  class StronaUslug extends Strona
  {
    private $przyciski2 = array("Inżynieria" => "inzynieria.php",
                                "Zgodność ze standardami" => "standardy.php",
                                "Zasoby ludzkie" => "zasoby.php",
                                "Dobór celów" => "cele.php"
                               );


    public function Wyswietl()
    {
      echo "<html>\n<head>\n";
      $this->WyswietlTytul();
      $this->WyswietlSlowaKluczowe();
      $this->WyswietlStyle();
      echo "</head>\n<body>\n";
      $this->WyswietlNaglowek();
      $this->WyswietlMenu($this->przyciski);
      $this->WyswietlMenu($this->przyciski2);
      echo $this->zawartosc;
      $this->WyswietlStopke();
      echo "</body>\n</html>\n";
    }
  }

  $uslugi=new StronaUslug();
  
  $uslugi->zawartosc="<p>Firma TLA Consulting oferuje kilka rodzajów usług.
                      Być może produktywność pracowników Państwa poprawiłaby się,
                      jeżeli Państwa firma zostałaby poddana inżynierii,
                      być może cały system potrzebuje właściwego doboru celów,
                      lub zmiany sposobu zarządzania zasobami ludzkimi.</p>";
                      
  $uslugi->Wyswietl();
?>